"use strict";
var $__utils__;
var path = require('path');
var cp = require('child_process');
var semver = require('semver');
var semverRegex = require('semver-regex');
var dargs = require('dargs');
var through = require('through2');
var utils = ($__utils__ = require("./utils"), $__utils__ && $__utils__.__esModule && $__utils__ || {default: $__utils__});
var which = utils.denodeify(require('which'));
var BIN = 'sass-convert';
var MINVERS = '>=3.4.5';
function exec(command) {
  var $__3;
  for (var args = [],
      $__1 = 1; $__1 < arguments.length; $__1++)
    args[$__1 - 1] = arguments[$__1];
  var deferred = utils.defer();
  var childProcess;
  args.push((function(err, stdout, stderr) {
    if (err) {
      deferred.reject(Object.assign(err, {
        message: (err.message + " \"" + command + "\" exited with error code " + err.code),
        stdout: stdout,
        stderr: stderr
      }));
    } else {
      deferred.resolve({
        childProcess: childProcess,
        stdout: stdout,
        stderr: stderr
      });
    }
  }));
  childProcess = ($__3 = cp).exec.apply($__3, $traceurRuntime.spread([command], args));
  return deferred.promise;
}
var BinaryError = function BinaryError(message) {
  $traceurRuntime.superConstructor($BinaryError).call(this, message);
  this.message = message || ("Could not find any executable for \"" + BIN + "\". Operation Aborted.");
};
var $BinaryError = BinaryError;
($traceurRuntime.createClass)(BinaryError, {get name() {
    return 'BinaryError';
  }}, {}, Error);
var VersionError = function VersionError(message) {
  $traceurRuntime.superConstructor($VersionError).call(this, message);
  this.message = message || ("Invalid \"" + BIN + "\" version, must be " + MINVERS);
};
var $VersionError = VersionError;
($traceurRuntime.createClass)(VersionError, {get name() {
    return 'VersionError';
  }}, {}, Error);
function checkBinary(bin) {
  function checkVersion(str) {
    var version = str.match(semverRegex())[0];
    return semver.satisfies(version, MINVERS);
  }
  function checkGlobal() {
    return which(bin).then((function() {
      return exec((bin + " -v"));
    }), (function() {
      throw new BinaryError();
    })).then((function(res) {
      if (!checkVersion(res.stdout)) {
        throw new VersionError();
      }
    }));
  }
  function checkBundle() {
    return which('bundle').then((function() {
      return exec(("bundle exec " + bin + " -v"));
    })).then((function(res) {
      if (!checkVersion(res.stdout)) {
        throw new VersionError();
      }
      return {bundler: true};
    }), (function(err) {
      throw new BinaryError();
    }));
  }
  return checkBundle().then(null, checkGlobal);
}
function checkBinaryCache() {
  if (!('promise' in checkBinaryCache)) {
    checkBinaryCache.promise = checkBinary(BIN);
  }
  return checkBinaryCache.promise;
}
var Converter = function Converter(options) {
  this.options = options || {};
  this.bundler = false;
};
($traceurRuntime.createClass)(Converter, {
  command: function() {
    var cmd = ((this.bundler ? 'bundle exec ' : '') + "sass-convert");
    var options = Object.assign(this.options, {
      'stdin': true,
      'no-cache': true
    });
    var allowed = ['from', 'to', 'dasherize', 'indent', 'old', 'default-encoding', 'unix-newlines', 'stdin', 'no-cache'];
    var args = dargs(options, [], allowed);
    return {
      cmd: cmd,
      args: args
    };
  },
  isTransformable: function(chunk) {
    var ext = path.extname(chunk.path);
    return chunk.isBuffer() && ext.endsWith(this.options.from);
  },
  convertFile: function(file, enc) {
    var deferred = utils.defer();
    var $__2 = this.cmdCache = this.cmdCache || this.command(),
        cmd = $__2.cmd,
        args = $__2.args;
    var child = cp.spawn(cmd, args);
    var converted;
    child.stdin.setEncoding(enc);
    child.stdin.write(file.contents);
    child.stdin.end();
    child.stdout.setEncoding(enc);
    child.stdout.on('data', (function(data) {
      converted = data;
    }));
    child.on('error', (function(err) {
      deferred.reject(err);
    }));
    child.on('close', (function(code, signal) {
      if (code === 0) {
        deferred.resolve(converted);
      }
    }));
    return deferred.promise;
  },
  stream: function() {
    var self = this;
    return through.obj(function(chunk, enc, cb) {
      var stream = this;
      if (!self.isTransformable(chunk)) {
        return cb(null, chunk);
      }
      checkBinaryCache().then((function(res) {
        self.bundler = res ? res.bundler : false;
        return self.convertFile(chunk, enc);
      })).then((function(converted) {
        chunk.contents = new Buffer(converted);
        cb(null, chunk);
      }), (function(err) {
        stream.emit('error', err);
        if (self.options.force) {
          return cb();
        }
        stream.destroy();
        stream.emit('end');
      }));
    });
  }
}, {});
module.exports = function(options) {
  return new Converter(options).stream();
};
module.exports.BinaryError = BinaryError;
module.exports.VersionError = VersionError;
